Exercises — ASE documentation

### Navigation

- index
- modules |
- Tutorials »

# Exercises

Exercise 2 contains a script which takes somewhat long time. For this reason you may want to submit the script to Niflheim in advance, before analyzing the results in Exercise 1.

- Siesta 1: Basis Sets
  - Part 1: Standard basis sets
  - Part 2: Optimized basis sets
  - Tips
- Siesta 2: Molecular Dynamics

### Navigation

- index
- modules |
- Tutorials »